@@ -975,14 +975,17 @@ formed, \n\n" % (model, attr)
                             STATS['objects'][model]['written'] += 1
                     
                 except xmlrpclib.Fault as err:
-                    error = unicode(err.faultString + (err.faultCode or ''))\
+                    try:
+                        error = unicode(err.faultString.split('\n')[-2])
+                    except:
+                        error = unicode(err.faultString + (err.faultCode or ''))\
                             or 'Unknown error (xmlrplib.Fault)'
                 except Exception as err:
                     error = unicode(err) or 'Unknown error (Exception)'
         if error:
             res = [False]
             state = 'none'
-            self._logger.warning("<%-25s> NOT CONSISTENT -> %s(%s)" %\
+            self._logger.error("<%-25s> id:%s %s" %\
                     (model, search, error), extra=STATS)
             self._logger.debug("<%-25s> id:%s|state:%s|%s" %\
                     (model, search, state, pformat(data)), extra=STATS)
